==> abstract_router-1.0.5.tar.gz: README.md <==
# Abstract Router

[![Build Status](https://travis-ci.org/dart-router/abstract-router.svg?branch=master)](https://travis-ci.org/dart-router/abstract-router)

[中文文档](./README.zh_cn.md)

The original intention of abstract routing is to implement a simple routing system for mapping URIs to specified handlers and to support binding of middleware to paths. It parses the parameter information, middleware, and processing functions carried by the URI and places it in the context of the `RouterContext` for the real routing system.


[API Documentation on pub.dev](https://pub.dev/documentation/abstract_router/latest/abstract-router/abstract-router-library.html)

[API Documentation on flutter-cn.io](https://pub.flutter-io.cn/documentation/abstract_router/latest/abstract-router/abstract-router-library.html)

MIT License

Copyright (c) 2019 bullub

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> abstract_router-1.0.7.tar.gz: README.md <==
# Abstract Router

[![Version](https://img.shields.io/badge/version-1.0.7-blue.svg)](https://pub.dev/packages/abstract_router)
[![Build Status](https://travis-ci.org/dart-router/abstract-router.svg?branch=master)](https://travis-ci.org/dart-router/abstract-router)
![Coverage](https://raw.githubusercontent.com/dart-router/abstract-router/master/coverage_badge.svg?sanitize=true)

[中文文档](./README.zh_cn.md)

The original intention of abstract routing is to implement a simple routing system for mapping URIs to specified handlers and to support binding of middleware to paths. It parses the parameter information, middleware, and processing functions carried by the URI and places it in the context of the `RouterContext` for the real routing system.


[API Documentation on pub.dev](https://pub.dev/documentation/abstract_router/latest/)

[API Documentation on flutter-cn.io](https://pub.flutter-io.cn/documentation/abstract_router/latest/)

MIT License

Copyright (c) 2019 bullub

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
